@@ -13,17 +13,17 @@ from pbpstats.resources.enhanced_pbp.stats_nba.turnover import StatsTurnover
 from pbpstats.resources.enhanced_pbp.stats_nba.violation import StatsViolation
 
 __all__ = [
-    'StatsEjection',
-    'StatsEndOfPeriod',
-    'StatsFieldGoal',
-    'StatsFoul',
-    'StatsFreeThrow',
-    'StatsJumpBall',
-    'StatsRebound',
-    'StatsReplay',
-    'StatsStartOfPeriod',
-    'StatsSubstitution',
-    'StatsTimeout',
-    'StatsTurnover',
-    'StatsViolation',
+    "StatsEjection",
+    "StatsEndOfPeriod",
+    "StatsFieldGoal",
+    "StatsFoul",
+    "StatsFreeThrow",
+    "StatsJumpBall",
+    "StatsRebound",
+    "StatsReplay",
+    "StatsStartOfPeriod",
+    "StatsSubstitution",
+    "StatsTimeout",
+    "StatsTurnover",
+    "StatsViolation",
 ]
